%% INPUT: Read loopdata and get run numbers (elements damaged)
fprintf('Reading loopdata...');

%Read in element numbers that have been used in analysis
file_loopdata='loopdata.inp';

fid_loopdata=fopen(file_loopdata);
if fid_loopdata<0
    disp('ERROR: Could not find file containing loop data!');
    disp(file_loopdata);
    logfile(11);
    return;
end
fprintf('............');

%Read header
fgets(fid_loopdata);   

%Read run identifiers
loopdata_instances=fscanf(fid_loopdata,'%d',[1,inf]);	

%Close
fclose(fid_loopdata);
fprintf('..................................................\t\tOK!\n');

%Get number of runs
nruns=length(loopdata_instances);

logfile(12);

%% INPUT: Read element-nodal connection
if exist('elem_node_connection.dat','file')
    fid=fopen('elem_node_connection.dat');
    tmp=textscan(fid,'%d %d %d','headerlines',1);
    %[element_node_conn(:,1) element_node_conn(:,2) element_node_conn(:,3)]=textread('elem_node_connection.dat','%d %d %d','headerlines',1);
    element_node_conn(:,1:3)=cell2mat(tmp);
    fclose(fid);
else
    disp('ERROR: Could not find elem_node_connection.dat!');
    return;
end
%% MEMORY: Prealloc (nruns)
    %Cells
    dir_res=cell(1,nruns);

    %Structs
    ErrorEst=struct('R',cell(422,1),'df',cell(422,1),'normr',cell(422,1));

    %Floats
    npos=zeros(nruns,1);
    nneg=zeros(nruns,1);
    polynom=zeros(nruns,2);
%% INPUT: Find result file, intact stucture
    fprintf('Getting result files...');

    %Find *.LIS file in PWD
    res_file_init_struct=dir('Init*.LIS');
    ninitfiles=size(res_file_init_struct);
    res_file_init={res_file_init_struct.name};

    if isempty(res_file_init)
        disp('ERROR: Could not find any initial Init*.LIS file!');
        logfile(13);
        return;
    elseif max(ninitfiles)>1
        disp('ERROR: Too many init files found!');
        disp(max(ninitfiles));
        logfile(14);
        return;
    end
    fprintf('...init...');
    logfile(15);
%% INPUT: Find result files, damaged scenarios

    %Find all *.LIS files in results folder
    res_files_struct=dir('./BATCH/RESULTS_BATCH/*.LIS');
    nresfiles=size(res_files_struct,1);

    %Memory alloc
    res_files=cell(nresfiles,1);
    run_id=zeros(nresfiles,1);

    fprintf('...runs...');
    %Extract file names from struct
    for i=1:nresfiles
        res_files(i,:)={res_files_struct(i).name};
    end
    if isempty(res_files)
        disp('ERROR: Could not find any *.LIS data file!');
        disp(res_files)
        logfile(16);
        return;
    end

    %Sort the run data against result files found
    fprintf('...sorting...');
    for i=1:nresfiles
        for j=1:nruns
            if ~isempty(strfind(char(res_files(i)),['-' num2str(loopdata_instances(j)) '_']))
                run_id(i)=loopdata_instances(j);
                break; %When found, go to next run (only one run per resfile)
            end
        end
    end
    fprintf('.........................\t\tOK!\n');
    logfile(17);
    toc
%% INPUT: Read in fatigue data, intact structure
    fprintf('Reading results...');

    %Read in the initial results
    [joint_init,damage_init,fatlif_init,member_init,member_type_init,scf_ax_init,scf_ip_init,scf_op_init,joint_cnct_init]=read_fat_dam(char(res_file_init));
    
    logfile(18);
%% MEMORY: Preallocate (nruns,nmemberschecked)

    %Preallocate memory based on initial file
    njoints=size(joint_init,2);

    joint=zeros(nruns,njoints);
    damage=zeros(nruns,njoints);
    fatlif=zeros(nruns,njoints);
    member=zeros(nruns,njoints);
    member_type=cell(nruns,njoints);
    scf_ax=zeros(nruns,njoints);
    scf_ip=zeros(nruns,njoints);
    scf_op=zeros(nruns,njoints);   

%% INPUT: Read in the fatigue data, damaged scenario
    %For each run, read in fatigue data
    prgs_tmp=0;
    for i=1:nruns
        prgs_tmp=progress(i,nruns,prgs_tmp);
        %Open result file
        file_res=(['./BATCH/RESULTS_BATCH/' char(res_files(i))]);
        [joint(i,:),damage(i,:),fatlif(i,:),member(i,:),member_type(i,:),scf_ax(i,:),scf_ip(i,:),scf_op(i,:)]=read_fat_dam(file_res);
    end
    
    %No interest in knowing member and menber_type for damaged case as
    %these are equal to initial (old MATLAB version does not support supressing with ~)
    clear member member_type;
    
%     %Also, member_type was great during debugging... NB: Used in
%     WriteCompactFiles (FILE_WRITEINPUT.m)
%     clear member_type_init;
    
    %Create a copy
    BACKUP_fatlif_init=fatlif_init;
    BACKUP_fatlif=fatlif;
    
    logfile(19);
%% INPUT: Clear some false results
    %Remove "false" result (no point in looking at fat life for element
    %that is "damaged")

    %Joint:
    for i=1:nruns
        joint_id_run=joint_cnct_init(member_init==run_id(i));
        for j=1:length(joint_id_run)
            ind=find(joint_cnct_init==joint_id_run(j));
            
            damage(i,ind)=damage_init(ind); %Reset damage to original, i.e. no change
            fatlif(i,ind)=fatlif_init(ind); %Reset fatlif to origianl, i.e. no change
        end
    end


    fprintf('\t\tOK!\n');
    toc

%% INPUT: Remove "false" data

%Find which members checked in fat-run that should be excluded
tmp=textscan(fopen('exclude_members.dat'),'%d');
excl_members=tmp{1};
cnt=1;
clear ind_noexcl_memb;
for i=1:njoints
    tmp=find(member_init(i)==excl_members);
    if ~any(tmp)
        ind_noexcl_memb(cnt)=i; %#ok<SAGROW>
        cnt=cnt+1;
    end
end

%Remove members to be excluded
fatlif_init=fatlif_init(ind_noexcl_memb);
damage_init=damage_init(ind_noexcl_memb);
joint_init=joint_init(ind_noexcl_memb);
joint_cnct_init=joint_cnct_init(ind_noexcl_memb);
member_init=member_init(ind_noexcl_memb);

tmp=zeros(nruns,size(fatlif_init,2));
tmp2=zeros(nruns,size(fatlif_init,2));
tmp3=zeros(nruns,size(fatlif_init,2));
for i=1:nruns
    tmp(i,:)=fatlif(i,ind_noexcl_memb);
    tmp2(i,:)=joint(i,ind_noexcl_memb);
    tmp3(i,:)=damage(i,ind_noexcl_memb);
end
fatlif=tmp;
joint=tmp2;
damage=tmp3;


%Find number of joints
njoints=length(fatlif_init);

