%###############################################################%
%################      POST_LIS_FILES_IV.m      ################%
%---------------------------------------------------------------%
%Script for post-process of results from SESAM FRAMEWORK        %
%                                                               %
%Written by : Arve Flesche (arve.flesche@akersolutions.com)     %
%Date       : 01.06.2012                                        %
%Version    : 0.4.5                                             %
%---------------------------------------------------------------%
%Function: Reads in fatigue damage data from *.LIS files,       %
%   and process all these results. The script is based upon     %
%   comparing several cases with one base case, and find the    %
%   difference/trends. Comparison is done using sets, and these %
%   should be defined in *.set files located in PWD             %
%Input: The *.LIS files should be located in:                   %
%   "PWD/BATCH/RESULTS_BATCH/". The command to use in           %
%   FRAMEWORK is:                                               %
%       "PRINT FATIGUE-CHECK-RESULTS <RUN-NAME>                 %
%       JOINT SELECTED-JOINTS ( ) FULL ABOVE 0.0"               %
%   A 'loopdata.inp' should be located in PWD to indicate       %
%   names to identify the different runs with:                  %
%                                                               %
%   loopdata.inp:                                               %
%   <HEADER>                                                    %
%   1437                                                        %
%   1438                                                        %
%   Run1                                                        %
%                                                               %
%   should apply to: *-1437_*.LIS, *-1438_*.LIS, *-Run1_*.LIS   %
%                                                               %
%   WARNING: The initial file to compare with needs to be       %
%       in PWD, and should be called Init*.LIS                  %
%   One or several *.set files shall be located in PWD:         %
%                                                               %
%   <SET-NAME>                                                  %
%   [LIST OF ELEMENT NUMBERS IN SET]                            %
%                                                               %
%   WARNING: Damaged elements can only be in ONE set!           %
%_______________________________________________________________%
%###############################################################%

close all;
fclose all;
clc;
%#ok<*MSNU> 

%Create log file
global fid_log1 fid_log_all1
file_name_log='logfile.log';
file_name_log_all='logfile_all.log';
fid_log1=fopen(file_name_log,'w');
fid_log_all1=fopen(file_name_log_all,'a');

logfile(1);

%fprintf('this is a mal for dotting........................................................');
%fprintf('\t\tOK!\n');

%% INPUT: Program run 
disp(' __________________________________________________________ ');
disp('|         POST LIS FILES: A Post-Processing Script         |');
disp('|              for Fatigue Damage Calculated By            |');
disp('|                    SESAM - FRAMEWORK                     |');
disp('|----------------------------------------------------------|');
disp('| Written by: Arve Flesche (arve.flesche@akersolutions.com)|');
disp('| Date      : 01.06.2012                                   |');
disp('| Version   : 0.4.5                                        |'); 
disp('|                                                          |');
disp('|           AKER SOLUTIONS MMO AS C&T BERGEN               |');
disp('|__________________________________________________________|');
fprintf('\n');

logfile(2);

%Define database status
INPUT_CONTROL;

%% FOLDER: Make folders
%Delete old plot files
% if delete_old==true
%     if exist('MATLAB PLOTS','dir')
%         [tmp1 tmp2 tmp3]=rmdir('MATLAB PLOTS','s');
%     end
% end

%% INPUT: Read LIS files
if exist('readinput.mat','file');
    check_use_old_read=input('Use previous read data (will override all of the above)? y / n (default=N if start from scratch=Y): ','s');
    if isempty(check_use_old_read)
        if read_input==true
            check_use_old_read='n';
        else
            check_use_old_read='y';
        end
    end
else
    check_use_old_read='n'; %if not exist, force read anyway
end
    
if strcmp(check_use_old_read,'n')
    logfile([],'Reading input...')
    INPUT_READ;

    %SCF not interesting @ the moment
    clear scf_ax scf_ip scf_op scf_ax_init scf_ip_init scf_op_init
    
    %Save input read to save time if run again
    save('readinput');
else
    tmp_dir_readinp=dir('readinput.mat');
    fprintf('Using data from %20s.................',tmp_dir_readinp.date);
    load('readinput.mat');
    fprintf('............................\t\tOK!\n');
    logfile([],['Using data from ' tmp_dir_readinp.date '...']);
end
        

% %% FILE: Write input data to compact ASCII files
% FILE_WRITEINPUT;


%% PROCESS: Results per run, sortet against set
PROCESS_RUNSET;


%% PROCESS: Results per run, sorted agianst run_id
PROCESS_RUNRUN;
%Note: Gives best filenames if PROCESS_RUNSET is run first (damage in set is part of filename, not just elem nr)

FILE_GENIESETS;

%% PROCESS: Find max Fatigue Accelerator Factor (extrem values) for each run
PROCESS_RUNFAF;


%% PROCESS: Find which joints that have minimum fatigue life when damaged
PROCESS_LOWFAT;


%% PROCESS: Check for correlation between FAF and RSR
PROCESS_CORR;

%% PROCESS: Define sets, divide fatlif into adjacent, parellel etc.
PROCESS_SET;

%% SAVE: All variables in workspace
save('run_variables');

fclose all;

