%Folders
if ~exist([pwd '/MATLAB PLOTS'],'dir')
    mkdir([pwd '/MATLAB PLOTS']);
end

if ~exist([pwd '/MATLAB PLOTS/FAF'],'dir')
    mkdir([pwd '/MATLAB PLOTS/FAF']);
end

if ~exist([pwd '/MATLAB PLOTS/FAF/CORRELATION'],'dir')
    mkdir([pwd '/MATLAB PLOTS/FAF/CORRELATION']);
end

if ~exist([pwd '/MATLAB PLOTS/FAF/CDF'],'dir')
    mkdir([pwd '/MATLAB PLOTS/FAF/CDF']);
end

if ~exist([pwd '/MATLAB PLOTS/FAF/LOGNORM'],'dir')
    mkdir([pwd '/MATLAB PLOTS/FAF/LOGNORM']);
end

if ~exist([pwd '/MATLAB FILES/FAF'],'dir')
    mkdir([pwd '/MATLAB FILES/FAF']);
end


%% GLOBAL (all runs, extreme in structure as whole)
faf_all=1./min(change_fatlif);
f1=figure('Visible','Off');
cdfplot(faf_all);
set(gca,'XScale','log');
xlabel('Fatigue Accelerator Factor');
title(['CDF-PLOT FATIGUE ACCELERATOR FACTOR' sprintf('\n') 'EXTREME VALUE ALL RUNS'],'FontSize',12);

print(f1,'-dpng',[pwd '\MATLAB PLOTS\FigureFatigueAccFactorCDFPlotExtValAllruns.png']);

close(f1);

%Method of moments fit
muy=mean(faf_all);
sigmay=std(faf_all);
vy=sigmay/muy;

muz=log(muy/(sqrt(vy^2+1)));
sigmaz=sqrt(log(vy^2+1));

f2=figure('Visible','Off');
probplot('lognormal',(faf_all));
% alpha=0.05;
% [parm, parmci]=lognfit(faf_all,alpha);
ln=@(faf_all,muz,sigmaz)cdf('logn',faf_all,muz,sigmaz);
h=probplot(gca,ln,[muz sigmaz]);
% hl=probplot(gca,ln,parmci(1,:));
% hh=probplot(gca,ln,parmci(2,:));
set(h,'color','r','linestyle','-');
% set(hl,'color','g','linestyle',':');
% set(hh,'color','g','linestyle',':');
title(['LOG-NORM PROBABILITY-PLOT FAF' sprintf('\n') 'EXTREME VALUE ALL RUNS'],'FontSize',12);
legend('MLE','Data','MM','Location','NW');
xlabel('Fatigue Accelerator Factor');

print(f2,'-dpng',[pwd '\MATLAB PLOTS\FAF\LOGNORM\FigureFatigueAccFactorLogNormProbPlotExtValAllruns.png']);

close(f2);

%% LOCAL: (all runs, extreme in sets)
faf_set_cell=cell(1,nsets);

for i=1:nsets
    if any(member_in_set==i)
        faf_tmp=1./(min(change_fatlif(:,member_in_set==i)));
        if isempty(faf_tmp)
            faf_tmp=1;
        end
        faf_set_cell(i)={faf_tmp};
        
        f1=figure('Visible','Off');
        cdfplot(faf_tmp);
        set(gca,'XScale','log');
        xlabel('Fatigue Accelerator Factor');
        title(['CDF-PLOT FATIGUE ACCELERATOR FACTOR' sprintf('\n') 'EXTREME VALUE ALL RUNS FOR SET: ' char(set_names(i))],'FontSize',12);
        
        print(f1,'-dpng',[pwd '\MATLAB PLOTS\FAF\CDF\FigureFatigueAccFactorCDFPlotExtValSet' char(set_names(i)) 'Allruns.png']);
        
        close(f1);
        
        %Method of moments fit
        muy=mean(faf_tmp);
        sigmay=std(faf_tmp);
        vy=sigmay/muy;
        
        muz=log(muy/(sqrt(vy^2+1)));
        sigmaz=sqrt(log(vy^2+1));
        
        f2=figure('Visible','Off');
        probplot('lognormal',(faf_tmp));
        ln=@(faf_all,muz,sigmaz)cdf('logn',faf_all,muz,sigmaz);
        h=probplot(gca,ln,[muz sigmaz]);
        set(h,'color','r','linestyle','-');
        title(['LOG-NORM PROBABILITY-PLOT FAF' sprintf('\n') 'EXTREME VALUE ALL RUNS FOR SET: ' char(set_names(i))],'FontSize',12);
        legend('MLE','Data','MM','Location','NW');
        xlabel('Fatigue Accelerator Factor');
        
        print(f2,'-dpng',[pwd '\MATLAB PLOTS\FAF\FigureFatigueAccFactorLogNormProbPlotExtValSet' char(set_names(i)) 'Allruns.png']);
        
        close(f2);
    else
        faf_set_cell(i)={0};
    end
end

%% SET: (dam in set, extreme in sets)
faf_setset_cell=cell(ndamsets,nsets);
faf_setset_max=zeros(nsets,nsets);

dotstyle=['o','x','+','*','s','d','v','^','<','>','p','h'];
f=figure('Visible','Off');cmap=colormap('lines');close(f);
cmap=cmap(1:7,:); %'Lines' colormap repeats itself after seven rows
for i=1:nsets
    f=figure('Visible','Off');
    hold on;
    set(gca,'XScale','log');
    cnt=2;  %Start at color nr 2
    cnt2=1; %Start at data point style 1
    stp=1;  %Jump one (stp=1) color in colormap
    for j=dam_in_set_unq
        faf_tmp=1./(min(change_fatlif(dam_in_set==j,member_in_set==i)));
        if isempty(faf_tmp)
            faf_tmp=1;
        end
        faf_setset_cell(j,i)={faf_tmp};
        faf_setset_max(j,i)=max((faf_tmp));

        [faf_set_ecdf x]=ecdf(cell2mat(faf_setset_cell(j,i)));
        pstr=[dotstyle(cnt2) '-']; %Get plotstyle
        h2=plot(gca,x,faf_set_ecdf,pstr);
        set(h2,'color',cmap(cnt,:));
        
        %Increase color vector index
        cnt=cnt+stp;
        if cnt>size(cmap,1); %Make sure it does not exceed number of colors
            cnt=1;
            cnt2=cnt2+1; %Use next data point style when color repeat
            if cnt2>length(dotstyle) %Keep below number of data point style
                cnt2=1;
            end
        end
    end
    legend(dam_in_set_unique_cell,'Location','EastOutside');
    xlabel('Fatigue Accelerator Factor');
    ylabel('F(x)');
    title(['CDF-PLOT FATIGUE ACCELERATOR FACTOR' sprintf('\n') 'EXTREME VALUE FOR SET: ' char(set_names(i))],'FontSize',12);
    
   set(f, 'OuterPosition', [0 50 900 600]);
   saveas(f,[pwd '\MATLAB PLOTS\FAF\FigureFatigueAccFactorCDFPlotExtValPerDamSetForSet' char(set_names(i)) '.fig'],'fig');
   
    
    %     %Method of moments fit
    %     muy=mean(faf_tmp);
    %     sigmay=std(faf_tmp);
    %     vy=sigmay/muy;
    %
    %     muz=log(muy/(sqrt(vy^2+1)));
    %     sigmaz=sqrt(log(vy^2+1));
    %
    %     f2=figure('Visible','Off');
    %     probplot('lognormal',(faf_tmp));
    %     ln=@(faf_all,muz,sigmaz)cdf('logn',faf_all,muz,sigmaz);
    %     h=probplot(gca,ln,[muz sigmaz]);
    %     set(h,'color','r','linestyle','-');
    %     title(['LOG-NORM PROBABILITY-PLOT FAF' sprintf('\n') 'EXTREME VALUE ALL RUNS FOR SET: ' char(set_names(i))],'FontSize',12);
    %     legend('MLE','Data','MM','Location','NW');
    %     xlabel('Fatigue Accelerator Factor');
    %
    %     print(f1,'-dpng',[pwd '\MATLAB PLOTS\FAF\FigureFatigueAccFactorLogNormProbPlotExtValSet' char(set_names(i)) 'Allruns.png']);
    %
    %     close(f2);
    
end
%% FILE: Write out cross-corrolated FAF_max to use with Excel (tab-delim)
mxfaf=faf_setset_max(dam_in_set_unq,:);
file_name=[pwd '\MATLAB FILES\FAF\MaxFaf.out'];
fid=fopen(file_name,'w');

fprintf(fid,'MAXIMUM FATIGUE ACCELERATOR FACTORS\n\n');
fprintf(fid,'      Damage set |\t');
for i=1:nsets
    fprintf(fid,'%16s\t',char(set_names(i)));
end
fprintf(fid,'\n');
for i=1:nsets+1
    fprintf(fid,'------------------------');
end
fprintf(fid,'\n');
for i=1:ndamsets
    fprintf(fid,'%16s',char(dam_in_set_unique_cell(i)));
    fprintf(fid,' |\t');
    for j=1:nsets
        fprintf(fid,'        %1.1e\t',mxfaf(i,j));
    end
    fprintf(fid,'\n');
end

fclose(fid);

%% DIFFERENCE: For each set all runs
%Make a plot showing differences
dotstyle=['o','x','+','*','s','d','v','^','<','>','p','h'];
f=figure('Visible','Off');
cmap=colormap('lines');
cmap=cmap(1:7,:); %'Lines' colormap repeats itself after seven rows
cnt=2;  %Start at color nr 2
cnt2=1; %Start at data point style 1
stp=1;  %Jump one (stp=1) color in colormap
hold on;
[faf_all_ecdf x]=ecdf(faf_all);
plot(x,faf_all_ecdf,'Linewidth',2);
set(gca,'XScale','log');
for i=1:nsets
    [faf_set_ecdf x]=ecdf(cell2mat(faf_set_cell(i)));
    pstr=[dotstyle(cnt2) '-']; %Get plotstyle
    h2=plot(gca,x,faf_set_ecdf,pstr);
    set(h2,'color',cmap(cnt,:));
    
    %Increase color vector index
    cnt=cnt+stp;
    if cnt>size(cmap,1); %Make sure it does not exceed number of colors
        cnt=1;
        cnt2=cnt2+1;
        if cnt2>length(dotstyle) %Keep below number of data point style
            cnt2=1;
        end
    end
end
legend(['All',set_names],'Location','EastOutside');
xlabel('Fatigue Accelerator Factor');
ylabel('F(x)');
title(['CDF-PLOT FATIGUE ACCELERATOR FACTOR' sprintf('\n') 'EXTREME VALUE IN SETS FOR ALL DAMAGE CASES'],'FontSize',12);

set(f, 'OuterPosition', [0 50 900 600]);
saveas(f,[pwd '\MATLAB PLOTS\FAF\FigureFatigueAccFactorCDFPlotExtValCompareSetsAllRuns.fig'],'fig');

close(f);


%% Check for correlation between FAF and Miner damage

%Create a log data set
x_data=log10(damage_init);
y_data=log10(faf_all);

%Correlation coefficient
[R P]=corrcoef(x_data,y_data);

rho_xy=R(1,2);

file_name=[pwd '\MATLAB FILES\CorrelationFAFvsMinerDamage.out'];
fid=fopen(file_name,'w');

fprintf(fid,'CORRELATION COEFFICIENT:\n\n');
fprintf(fid,'rho_xy:\t%.3f\n',rho_xy);

fclose(fid);

%%
%Create a poly-fit (order=1, i.e. linear) to data
[polynom,ErrorEst]=polyfit(x_data,y_data,1);
regr_line=polyval(polynom,x_data,ErrorEst);


%Since regression is done on logarithmic data, convert results back to get
%correct axis when plotting in log-log
regr_line_sort=sort(10.^regr_line);
x_line_sort=sort(damage_init,2,'descend');


f=figure('Visible','Off');
loglog(damage_init,faf_all,'.',x_line_sort,regr_line_sort,'-');
title('CORRELATION FAF Vs MINER DAMAGE');
xlabel('Miner Damage');
ylabel('Fatigue Acceleration Factor');
legend('Data','Regression');

set(f, 'PaperUnits', 'points');
set(f, 'PaperSize', [500 360]);
set(f, 'PaperPositionMode', 'manual');
set(f, 'PaperPosition', [0 0 500 360]);
saveas(f,[pwd '\MATLAB PLOTS\FigureFAFCorrelationFatigueDamageAllRuns.fig'],'fig');
saveas(f,[pwd '\MATLAB PLOTS\FAF\FigureFAFCorrelationFatigueDamageAllRuns.fig'],'fig');

% print(f,'-dpng',[pwd '\MATLAB PLOTS\FigureFAFCorrelationFatigueDamageAllRuns.png']);

close(f);

%% Check for correlation for each set

for i=1:nsets
    if any(member_in_set==i)
        %Create a log data set
        x_data=log10(damage_init(member_in_set==i));
        y_data=log10(faf_all(member_in_set==i));
        
        %Create a poly-fit (order=1, i.e. linear) to data
        [polynom,ErrorEst]=polyfit(x_data,y_data,1);
        regr_line=polyval(polynom,x_data,ErrorEst);
        
        %Since regression is done on logarithmic data, convert results back to get
        %correct axis when plotting in log-log
        regr_line_sort=sort(10.^regr_line);
        x_line_sort=sort(damage_init(member_in_set==i),2,'descend');
        
        f=figure('Visible','Off');
        loglog(damage_init(member_in_set==i),faf_all(member_in_set==i),'.',x_line_sort,regr_line_sort,'-');
        title(['CORRELATION FAF Vs MINER DAMAGE' sprintf('\n') 'FOR SET: ' char(set_names(i))]);
        xlabel('Miner Damage');
        ylabel('Fatigue Acceleration Factor');
        legend('Data','Regression');
        
        print(f,'-dpng',[pwd '\MATLAB PLOTS\FAF\CORRELATION\FigureFAFCorrelationFatigueDamageForSet' char(set_names(i)) 'AllRuns.png']);

        close(f);
    end
end


% %% CDF-plot Fatigue Life Utilization Extreme Value (highest)
% fatigue_life=[fatlif; fatlif_init];
% service_life=40;
% 
% utilization_max=max(40./fatigue_life,[],2);
% 
% [cdf_util_max x_util_max]=ecdf(utilization_max);
% 
% %Make a plot showing differences
% f1=figure('Visible','Off');
% pstr='-'; %Get linestyle
% h=plot(x_util_max,cdf_util_max,pstr);
% set(gca,'XScale','log');
% title(['CDF-PLOT UTILIZATION EXTREME VALUES' sprintf('\n') 'SERVICE LIFE: ' num2str(service_life) ' YEARS'],'FontSize',12);
% %Add text for all Util<=1;
% cdf_util1=max(cdf_util_max(x_util_max<=1));
% text(1,cdf_util1,['\uparrow F_X(x=1) = ' num2str(round(100*cdf_util1)) ' [%]'],'EdgeColor','red','VerticalAlignment','top');
% %Add text for all Fatlif~=Init
% util_init=40/min(fatlif_init);
% cdf_util_init=max(cdf_util_max(x_util_max<=util_init));
% text(util_init,cdf_util_init,['\uparrow F_X(x<=x_i_n_i_t) = ' num2str(round(100*cdf_util_init)) ' [%]'],'EdgeColor','red','VerticalAlignment','top');
% 
% print(f1,'-dpng',[pwd '\MATLAB PLOTS\FigureFatigueLifeUtilizationExtremeValue.png']);
% 
% close(f1);



%%
%Convert to PNG
saveaspng([pwd '\MATLAB PLOTS\FAF'],12,12,1,1);



