%Folder
if ~exist([pwd '/MATLAB PLOTS'],'dir')
    mkdir([pwd '/MATLAB PLOTS']);
end

%Structs
ErrorEst=struct('R',cell(nruns,1),'df',cell(nruns,1),'normr',cell(nruns,1));

%Floats
npos=zeros(nruns,1);
nneg=zeros(nruns,1);
polynom=zeros(nruns,2);
fitted_line_log=zeros(nruns,size(fatlif_init,2));

%% PROCESS: Calculate ratio for initial/damaged fatlif
fatlif_init_mat=ones(1,size(fatlif,1))'*fatlif_init;
change_fatlif=fatlif./fatlif_init_mat;


%% PROCESS: Regression on data
fprintf('Process results...');

%Create a log data set
fatlif_init_log=log10(fatlif_init);
fatlif_log=log10(fatlif);


%Create a poly-fit (order=1, i.e. linear) to data
for i=1:nruns
    [polynom(i,:),ErrorEst(i,:)]=polyfit(fatlif_init_log,fatlif_log(i,:),1);
    fitted_line_log(i,:)=polyval(polynom(i,:),fatlif_init_log,ErrorEst(i,:));   
end

%Since regression is done on logarithmic data, convert results back to get
%correct axis when plotting in log-log
fitted_line=sort(10.^fitted_line_log,2);
fitted_line_x=sort(fatlif_init,2);

%Create limit lines, i.e. change +/- 20 %
%Linear: No change (y=x)
x_regr=fatlif_init;

%Make high/low limits based on input
delta_fat=threshold_fat/100;
y_low=(1-delta_fat)*x_regr;
y_high=(1+delta_fat)*x_regr;

%Sort limit lines to get better view
[x_sort I]=sort(x_regr);
y_low_sort=y_low(I);
y_high_sort=y_high(I);


%Calculate Coefficient of determination for the log10() data
SStot=sum((fatlif_log-mean(fatlif_log,2)*ones(1,njoints)).^2,2);
SSerr=sum((fatlif_log-fitted_line_log).^2,2);

Rsq=1-SSerr./SStot;

%% PROCESS: Mean change and Std for single joint sorted against all runs
fprintf('...statistic');

muj=zeros(1,njoints);
stdj=zeros(1,njoints);

mx=[0.8 0.9 1];

for j=1:length(mx)
    for i=1:njoints
        tmp=change_fatlif(:,i);
        muj(i)=mean(tmp(tmp<=mx(j)));
        stdj(i)=std(tmp(tmp<=mx(j)));
    end

    f=figure('Visible','Off');
    plot(1:njoints,[muj;stdj],'.');
    legend('Mean','Std','Location','East');
    title(['CHANGE IN FATIGUE LIFE (R_3<=', num2str(mx(j)) ')'],'FontSize',12);
    xlabel('Joint Member count');
    ylabel('Value');
    
    set(f, 'PaperUnits', 'points');
    set(f, 'PaperSize', [500 360]);
    set(f, 'PaperPositionMode', 'manual');
    set(f, 'PaperPosition', [0 0 500 360]);
    saveas(f,[pwd '\MATLAB PLOTS\FigureMeanStdJointLT' num2str(mx(j)) 'AllRuns.fig'],'fig');

    close(f);
end


%% PROCESS: Characteristics of fatigue life, fit LogNorm
fprintf('...fitting');

%Number of bins to divide into
nbins=10;

%X-vector
xx = linspace(0,max(log10(fatlif_init(fatlif_init~=1.0000e+10))));

%Memory alloc based on above sizes
yy=zeros(nruns,length(xx));
yyy=zeros(nruns,length(xx));
ybin=zeros(nruns,nbins);
n=zeros(nruns,nbins);
x=zeros(nruns,nbins);
params=zeros(nruns,2);
conflb=zeros(nruns,2);
confub=zeros(nruns,2);
gm1=zeros(nruns,1);
gm2=zeros(nruns,1);
mu=zeros(nruns,1);
sigma=zeros(nruns,1);

fatlif_logged=cell(nruns,1);
fatlif_logged_joint=cell(njoints,1);

for i=1:nruns
    y=log10(fatlif(i,fatlif(i,:)~=1.0000e+10));
    %In case of neg val, set to 0.1 or something
    y(y<=0)=0.1;
    
    fatlif_logged(i)={y};
    
    %Create histogram
    [n(i,:),x(i,:)] = hist(y,nbins);
    
    %Fit
    [params(i,:) pci]=lognfit(y);
    conflb(i,:)=pci(1,:); %lower bound
    confub(i,:)=pci(2,:); %upper bound
    yy(i,:)=lognpdf(xx,params(i,1),params(i,2))*length(y)*(x(i,2)-x(i,1));
    yyy(i,:)=logncdf(xx,params(i,1),params(i,2));
    ybin(i,:)=lognpdf(x(i,:),params(i,1),params(i,2))*length(y)*(x(i,2)-x(i,1));
    
    %Calc skew and kurtos
    gm1(i)=skewness(y);
    gm2(i)=kurtosis(y);
    
    %MEAN and STD
    mu(i)=log10(mean(fatlif(i,fatlif(i,:)~=1.0000e+10)));
    sigma(i)=log10(std(fatlif(i,fatlif(i,:)~=1.0000e+10)));
end

%Initial data
y0=log10(fatlif_init(fatlif_init~=1.0000e+10));
%In case of neg val, set to 0.1 or something
y0(y0<=0)=0.1;

%MEAN and STD
mu0=log10(mean(fatlif_init(fatlif_init~=1.0000e+10)));
sigma0=log10(std(fatlif_init(fatlif_init~=1.0000e+10)));

%Calc skew and kurtos
gm10=skewness(y0);
gm20=kurtosis(y0);

%Create histogram
[n0,x0] = hist(y0,nbins);

%Fit
params0 = lognfit(y0);
yy0 = lognpdf(xx,params0(1),params0(2)) * length(y0) * (x0(2)-x0(1));
yyy0 = logncdf(xx,params0(1),params0(2));
ybin0=lognpdf(x0,params0(1),params0(2))*length(y0)*(x0(2)-x0(1));

%Empirical CDF
[Y0 X0]=ecdf(y0);

%% PROCESS: Test LogNorm fit with chi^2 test
alpha=0.001;

%Initial
[h0,p0,stats0]=chi2gof(x0,'ctrs',x0,'frequency',n0,'expected',ybin0,'alpha',alpha,'nparams',2);

%Impaired
h=zeros(1,nruns);
p=zeros(1,nruns);
stats=struct('chi2stat',cell(nruns,1),'df',cell(nruns,1),'edges',cell(nruns,1),'O',cell(nruns,1),'E',cell(nruns,1));
chi_sq=zeros(1,nruns);

for i=1:nruns
    [h(i),p(i),stats(i)]=chi2gof(x(i,:),'ctrs',x(i,:),'frequency',n(i,:),'expected',ybin(i,:),'alpha',alpha,'nparams',2);
    chi_sq(i)=stats(i).chi2stat;
end


%Collect number of failed tests
n_h=hist(h,2);

%% PLOT: Probabilistic fit
%PDF and Histogram
f1=figure('Visible','Off');
hold on
ib=bar(x0,n0,'hist');
dp=plot(xx,yy,':');
ip=plot(xx,yy0,'g','Linewidth',3);
legend([ib, ip, dp(1)],'Initial Data','Initial Fit','Impaired Fits');
xlabel('log_1_0(fatigue life)');
ylabel('Frequency');
title(['FATIGUE LIFE (log_1_0)' sprintf('\n') 'PDF LOG-NORM FIT'],'FontSize',12);

saveas(f1,[pwd '\MATLAB PLOTS\FigurePDFLogNormFitAllRunsNoScale.fig'],'fig');
set(f1, 'PaperUnits', 'points');
set(f1, 'PaperSize', [500 360]);
set(f1, 'PaperPositionMode', 'manual');
set(f1, 'PaperPosition', [0 0 500 360]);
saveas(f1,[pwd '\MATLAB PLOTS\FigurePDFLogNormFitAllRuns.fig'],'fig');

hold off
close(f1);


%CDF
f2=figure('Visible','Off');
hold on
ib=plot(X0,Y0,'b','Linewidth',3);
dp=plot(xx,yyy,':');
ip=plot(xx,yyy0,'g','Linewidth',3);
legend([ib, ip, dp(1)],'Initial Data','Initial Fit','Impaired Fits','Location','NorthWest');
xlabel('log_1_0(fatigue life)');
ylabel('Cummulative Probability');
title(['FATIGUE LIFE (log_1_0)' sprintf('\n') 'CDF LOG-NORM FIT'],'FontSize',12);

saveas(f2,[pwd '\MATLAB PLOTS\FigureCDFLogNormFitAllRunsNoScale.fig'],'fig');
set(f2, 'PaperUnits', 'points');
set(f2, 'PaperSize', [500 360]);
set(f2, 'PaperPositionMode', 'manual');
set(f2, 'PaperPosition', [0 0 500 360]);
saveas(f2,[pwd '\MATLAB PLOTS\FigureCDFLogNormFitAllRuns.fig'],'fig');

hold off
close(f2);


%LogNorm fit params
f3=figure('Visible','Off');
subplot(2,1,1);
plot((1:nruns)',params(:,1),'.',[1 nruns],[params0(1) params0(1)]);
legend('Impaired','Initial');
xlabel('Run#');
ylabel('$\hat{\mu_Z}$','Interpreter','latex','FontSize',14);
title('MEAN LOG-NORM FIT FATIGUE LIFE (log_1_0)','FontSize',12); 

subplot(2,1,2);
plot((1:nruns)',params(:,2),'.',[1 nruns],[params0(2) params0(2)]);
legend('Impaired','Initial');
xlabel('Run#');
ylabel('$\hat{\sigma_Z}$','Interpreter','latex','FontSize',14);
title('STD LOG-NORM FIT FATIGUE LIFE (log_1_0)','FontSize',12);

set(f3, 'PaperUnits', 'points');
set(f3, 'PaperSize', [500 360]);
set(f3, 'PaperPositionMode', 'manual');
set(f3, 'PaperPosition', [0 0 500 360]);
saveas(f3,[pwd '\MATLAB PLOTS\FigureLogNormFitParametersAllRuns.fig'],'fig');

close(f3);


%Data mean/std
f4=figure('Visible','Off');
subplot(2,1,1);
plot((1:nruns)',mu,'.',[1 nruns],[mu0 mu0]);
legend('Impaired','Initial');
xlabel('Run#');
ylabel('\mu _(_l_o_g_1_0_)','FontSize',14);
title('MEAN FATIGUE LIFE','FontSize',12); 

subplot(2,1,2);
plot((1:nruns)',sigma,'.',[1 nruns],[sigma0 sigma0]);
legend('Impaired','Initial');
xlabel('Run#');
ylabel('\sigma _(_l_o_g_1_0_)','FontSize',14);
title('STD FATIGUE LIFE','FontSize',12);

set(f4, 'PaperUnits', 'points');
set(f4, 'PaperSize', [500 360]);
set(f4, 'PaperPositionMode', 'manual');
set(f4, 'PaperPosition', [0 0 500 360]);
saveas(f4,[pwd '\MATLAB PLOTS\FigureDataMeanStdAllRuns.fig'],'fig');

close(f4);


%Data skew/kurtosis
f5=figure('Visible','Off');
plot(gm1.^2,gm2,'.',gm10^2,gm20,'*g',gm1.^2,(3+3/2*gm1.^2),':',gm1.^2,1.9315*gm1.^2+3,':',gm1.^2,gm1.^2+1,'-');
grid on
legend('Impaired','Initial','Gamma-dist','Log-Norm','Top lim');
title('FATIGUE LIFE DATA (log_1_0) CHARACTERIZATION','FontSize',12);
xlabel('\gamma_1^2 (skewness^2)');
ylabel('\gamma_2 (kurtosis)');
axis ij;

set(f5, 'PaperUnits', 'points');
set(f5, 'PaperSize', [500 360]);
set(f5, 'PaperPositionMode', 'manual');
set(f5, 'PaperPosition', [0 0 500 360]);
saveas(f5,[pwd '\MATLAB PLOTS\FigureDataSkewKurtosisAllRuns.fig'],'fig');

close(f5);

%Plot results of hypothesis
f6=figure('Visible','Off');
subplot(2,1,1);
plot(find(h==0),h(h==0),'+',find(h>0),h(h>0),'*',[1 nruns],[h0 h0]);
axis([0 nruns+1 -0.05 1.05]);
title(['\chi^2 TEST RESULTS LOG-NORM FIT' sprintf('\n') '1-\alpha=' num2str(1-alpha)],'FontSize',12);
legend('Cannot Reject H0','Reject H0','Initial fit','Location','East');
xlabel('Run#');
ylabel('H_0');

subplot(2,1,2);
pie(n_h);
legend('Cannot Reject H0','Reject H0','Location','EastOutside');

set(f6, 'PaperUnits', 'points');
set(f6, 'PaperSize', [500 360]);
set(f6, 'PaperPositionMode', 'manual');
set(f6, 'PaperPosition', [0 0 500 360]);
saveas(f6,[pwd '\MATLAB PLOTS\FigureChiSquareTestLogNormFitAlpha' num2str(1-alpha) 'AllRuns.fig'],'fig');

close(f6);


%Empirical CDF
f7=figure('Visible','Off');
hold on
for i=1:nruns
    [Y XX]=ecdf(cell2mat(fatlif_logged(i)));
    plot(XX,Y,':r');
end
xlabel('log_1_0(fatigue life)');
ylabel('Cummulative Probability');
title(['FATIGUE LIFE' sprintf('\n') 'EMPIRICAL CDF'],'FontSize',12); 
hold off

set(f7, 'PaperUnits', 'points');
set(f7, 'PaperSize', [500 360]);
set(f7, 'PaperPositionMode', 'manual');
set(f7, 'PaperPosition', [0 0 500 360]);
saveas(f7,[pwd '\MATLAB PLOTS\FigureEmpiricalCDFAllRuns.fig'],'fig');

close(f7)


f8=figure('visible','Off');
lim=2;

h=subplot(2,1,1);
plot(xx,yyy,':');
e=find(xx<=lim, 1, 'last' );
tmp=yyy(:,1:e);
mx=max(max(tmp,[],2));
if mx==0
    mx=0.1;
end
%axis([0 lim 0 mx]);
set(h,'XLim',[0 lim],'YLim',[0 mx]);
title(['FATIGUE LIFE' sprintf('\n') 'CDF LOG-NORM FIT'],'FontSize',12); 
xlabel('log_1_0(fatigue life)');
ylabel('Cummulative Probability');

subplot(2,1,2);
hold on
for i=1:nruns
    [Y XX]=ecdf(cell2mat(fatlif_logged(i)));
    plot(XX,Y,':r');
    if any(Y(find(XX<=lim))>mx) %#ok<FNDSB>
        mx=max(Y(find(XX<=lim))); %#ok<FNDSB>
        set(h,'XLim',[0 lim],'YLim',[0 mx]); %change axes on first subplot
    end
end
axis([0 lim 0 mx]);
title(['FATIGUE LIFE' sprintf('\n') 'EMPIRICAL CDF'],'FontSize',12); 
xlabel('log_1_0(fatigue life)');
ylabel('Cummulative Probability');
hold off

set(f8, 'PaperUnits', 'points');
set(f8, 'PaperSize', [500 360]);
set(f8, 'PaperPositionMode', 'manual');
set(f8, 'PaperPosition', [0 0 500 360]);
saveas(f8,[pwd '\MATLAB PLOTS\FigureEmpiricalVsFitCDFCloseUpAllRuns.fig'],'fig');

close(f8)
fprintf('............... \t\tOK!\n');
%% PLOT: XY plots and bar plot
if create_plots==true
    fprintf('Creating plots....');
    
    if ~exist([pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR RUN'],'dir')
        mkdir([pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR RUN']);
    end
    
    if ~exist([pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR RUN'],'dir')
        mkdir([pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR RUN']);
    end
    
    if ~exist([pwd '/MATLAB PLOTS/PROB FIT PLOTS PR RUN'],'dir')
        mkdir([pwd '/MATLAB PLOTS/PROB FIT PLOTS PR RUN']);
    end
    
%     if ~exist([pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR JOINT'],'dir')
%         mkdir([pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR JOINT']);
%     end
    
    if ~exist([pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR JOINT'],'dir')
        mkdir([pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR JOINT']);
    end
    
%     if ~exist([pwd '/MATLAB PLOTS/PROB FIT PLOTS PR JOINT'],'dir')
%         mkdir([pwd '/MATLAB PLOTS/PROB FIT PLOTS PR JOINT']);
%     end    

   
    tmp_prgs=0;
    for i=1:nruns
        tmp_prgs=progress(i,nruns,tmp_prgs);
        
        %Get change ratios
        tmp=change_fatlif(i,change_fatlif(i,:)<=2);
        f1=figure('Visible','Off');
        dbin=2/21;
        bins=dbin/2:dbin:2-dbin/2;
        hist(tmp,bins);
        xlabel('Ratio fatigue life (R_3)');
        ylabel('Frequency');
        try
            fnm=[pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR RUN/FigureHistR3DamIn' strrep(char(dam_in_set_cell(i)),' ','') 'CaseEL' num2str(run_id(i))];
            title(['HISTOGRAM RATIO FATIGUE LIFE' sprintf('\n') 'CASE: ' num2str(run_id(i)) ' (' char(dam_in_set_cell(i)) ')'],'FontSize',12);
        catch err
            fnm=[pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR RUN/FigureHistR3CaseEL' num2str(run_id(i))];
            title(['HISTOGRAM RATIO FATIGUE LIFE' sprintf('\n') 'CASE: ' num2str(run_id(i))],'FontSize',12);
        end
        
        set(f1, 'PaperUnits', 'points');
        set(f1, 'PaperSize', [500 360]);
        set(f1, 'PaperPositionMode', 'manual');
        set(f1, 'PaperPosition', [0 0 500 360]);
        saveas(f1,[fnm '.fig'],'fig');
        
        close(f1);
        
        
        %Individual prob fits/hist
        f3=figure('Visible','Off');
        hold on
        [NN xxx]=hist(cell2mat(fatlif_logged(i)),nbins);
        ib=bar(xxx,NN,'hist');
        dp=plot(xx,yy(i,:),'g','Linewidth',3);
        legend([ib, dp],'Damaged Data','Fit');
        xlabel('log_1_0(fatigue life)');
        ylabel('Frequency');
        hold off
        if ~isempty(dam_in_set_cell(i))
            fnm=[pwd '/MATLAB PLOTS/PROB FIT PLOTS PR RUN/FigureProbFatlifFitDamIn' strrep(char(dam_in_set_cell(i)),' ','') 'CaseEL' num2str(run_id(i))];
            title(['FATIGUE LIFE' sprintf('\n') 'PDF LOG-NORM FIT CASE: ' num2str(run_id(i)) ' (' char(dam_in_set_cell(i)) ')'],'FontSize',12); 
        else
            fnm=[pwd '/MATLAB PLOTS/PROB FIT PLOTS PR RUN/FigureProbFatlifFitCaseEL' num2str(run_id(i))];
            title(['FATIGUE LIFE' sprintf('\n') 'PDF LOG-NORM FIT CASE: ' num2str(run_id(i))],'FontSize',12); 
        end
        
        set(f3, 'PaperUnits', 'points');
        set(f3, 'PaperSize', [500 360]);
        set(f3, 'PaperPositionMode', 'manual');
        set(f3, 'PaperPosition', [0 0 500 360]);
        saveas(f3,[fnm '.fig'],'fig');
        
        close(f3);
        

        %Plot X-Y with regression and +/- X [%]  lines
        f2=figure('Visible','Off');
        loglog(fitted_line_x,fitted_line(i,:),'g-',fatlif_init,fatlif(i,:),'b.',x_sort,y_high_sort,'r--',x_sort,y_low_sort,'r--');
        xlabel('Initial Fatigue Life');
        ylabel('Damaged Fatigue Life');
        legend(['Regression Line (R^2=' num2str(Rsq(i),3) ')'],'Data',[num2str(delta_fat*100) ' % change'],'Location','NorthWest');
        if ~isempty(dam_in_set_cell(i))
            fnm=[pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR RUN/FigureXYRegrFatigueLifeDamIn' strrep(char(dam_in_set_cell(i)),' ','') 'CaseEL' num2str(run_id(i))];
            title(['X-Y PLOT FATIGUE LIFE' sprintf('\n') 'CASE: ' num2str(run_id(i)) ' (' char(dam_in_set_cell(i)) ')'],'FontSize',12);
        else
            fnm=[pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR RUN/FigureXYRegrFatigueLifeCaseEL' num2str(run_id(i))];
            title(['X-Y PLOT FATIGUE LIFE' sprintf('\n') 'CASE: ' num2str(run_id(i))],'FontSize',12);
        end
        
        set(f2, 'PaperUnits', 'points');
        set(f2, 'PaperSize', [500 360]);
        set(f2, 'PaperPositionMode', 'manual');
        set(f2, 'PaperPosition', [0 0 500 360]);
        saveas(f2,[fnm '.fig'],'fig');
             
        close(f2);    

    end
    fprintf('\t\tOK!\n');
end

%% HISTOGRAM
if create_plots==true
    fprintf('Creating plots....');
    %---------------------------------------------------------------------------------------------------------------------------------------------
    %Sort on joint instead of run
    tmp_prgs=0;
    for i=1:njoints
        tmp_prgs=progress(i,njoints,tmp_prgs);
        
        %Get change ratios
        tmp=change_fatlif(change_fatlif(:,i)<=2,i);
        f1=figure('Visible','Off');
        dbin=2/21;
        bins=dbin/2:dbin:2-dbin/2;
        hist(tmp,bins);
        xlabel('Ratio fatigue life (R_3)');
        ylabel('Frequency');
        if ~isempty(member_in_set(i))
            fnm=[pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR JOINT/FigureHistR3Jointloc' strrep(char(set_names(member_in_set(i))),' ','') 'MemberEL' num2str(member_init(i))];
            title(['HISTOGRAM RATIO FATIGUE LIFE' sprintf('\n') 'FOR MEMBER: ' num2str(member_init(i)) ' (' char(set_names(member_in_set(i))) ')'],'FontSize',12);
        else
            fnm=[pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR JOINT/FigureHistR3MemberEL' num2str(member_init(i))];
            title(['HISTOGRAM RATIO FATIGUE LIFE' sprintf('\n') 'FOR MEMBER: ' num2str(member_init(i))],'FontSize',12);
        end
        
        set(f1, 'PaperUnits', 'points');
        set(f1, 'PaperSize', [500 360]);
        set(f1, 'PaperPositionMode', 'manual');
        set(f1, 'PaperPosition', [0 0 500 360]);
        saveas(f1,[fnm '.fig'],'fig');

        close(f1);
    end
    fprintf('\t\tOK!\n');
    
    %Convert fig to PNG
    saveaspng([pwd '\MATLAB PLOTS\HISTOGRAM PLOTS PR RUN'],14,14,1,2);
    saveaspng([pwd '\MATLAB PLOTS\PROB FIT PLOTS PR RUN'],14,14,1,2);
    saveaspng([pwd '\MATLAB PLOTS\XY PLOTS REGRESSION PR RUN'],14,14,1,2);
    saveaspng([pwd '\MATLAB PLOTS\HISTOGRAM PLOTS PR JOINT'],14,14,1,2);
end


%Convert fig to PNG
saveaspng([pwd '\MATLAB PLOTS'],14,14,1,2);









