%Folders
if ~exist([pwd '/MATLAB PLOTS'],'dir')
    mkdir([pwd '/MATLAB PLOTS']);
end

if ~exist([pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR SET'],'dir')
    mkdir([pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR SET']);
end

if ~exist([pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR SET'],'dir')
    mkdir([pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR SET']);
end

if ~exist([pwd '/MATLAB PLOTS/PROB FIT PLOTS PR SET'],'dir')
    mkdir([pwd '/MATLAB PLOTS/PROB FIT PLOTS PR SET']);
end


%% PROCESS: Find in which Set members belong to
fprintf('...finding sets');
%Read in info about members in sets
sets_strct=dir('*.set');

nsetfiles=length(sets_strct);
nsets=nsetfiles;
if ~nsetfiles>0
    disp('ERROR! At least one *.set file should be in PWD!');
    logfile(21);
    return;
end

%Memory alloc
set_file=cell(1,nsetfiles);
dam_in_set_cell=cell(1,nruns);
set_names=cell(1,nsetfiles);
set_members=zeros(nsetfiles,1); %min memory requirement
set_members_cell=cell(1,nsetfiles);

%Structs
ErrorEst=struct('R',cell(nsets,1),'df',cell(nsets,1),'normr',cell(nsets,1));

%Floats
polynom_set=zeros(nsets,2);
fatlif_set=zeros(nsets,1000);        %Guess a size, zeros will be ignored later
fatlif_init_set=zeros(nsets,1000);   %Guess a size, zeros will be ignored later
member_in_set=zeros(1,njoints);
dam_in_set=zeros(1,nruns);


%Get set data
for i=1:nsetfiles
    set_file(i)=cellstr(sets_strct(i).name);
    fid_set=fopen(char(set_file(i)));
    if fid_set<0
        disp('ERROR: Could not open set file!');
        disp(char(set_file(i)));
        logfile(22);
        return;
    end
    
    %Read header
    set_names(i)=cellstr(fgets(fid_set));
    tmp=fscanf(fid_set,'%d');
    set_members_cell(i)={tmp};
    
    for j=1:length(tmp)
        set_members(i,j)=tmp(j);
    end
    
    fclose(fid_set);
end


%Get damage in set
for i=1:nruns
    [r c]=find(run_id(i)==set_members);
    if length(r)>1 || length(c)>1
        disp(' ');
        disp('ERROR! Damaged member defined in several sets!');
        disp(run_id(i));
        input('Press ENTER to continue...')
    elseif isempty(r) || isempty(c)
        disp(' ');
        disp('ERROR! Damaged member not defined in any set!');
        disp(run_id(i));
        input('Press ENTER to continue...')
    end
    dam_in_set_cell(i)=set_names(r);
    dam_in_set(i)=r;
end

%Unique damage in set trends
dam_in_set_unq=unique(dam_in_set);

%Get joint/member location
for i=1:njoints
    [r c]=find(member_init(i)==set_members);
    if length(r)>1 || length(c)>1
        disp(' ');
        disp('ERROR! Member defined in several sets!');
        disp(member_init(i));
        disp(set_names(r));
        input('Press ENTER to continue...')
    elseif isempty(r) || isempty(c)
        disp(' ');
        disp('ERROR! Member not defined in any set!');
        disp(member_init(i));
        input('Press ENTER to continue...')
    else
        member_in_set(i)=r;
    end
    
end


%Collect fatlif based on sets
cnt_set=zeros(1,nsets);
for i=1:nruns
    for j=1:nsets
        tmp=fatlif(i,member_in_set==j);
        tmp2=fatlif_init(member_in_set==j);
        for k=1:length(tmp)
            cnt_set(j)=cnt_set(j)+1;
            fatlif_set(j,cnt_set(j))=tmp(k);
            fatlif_init_set(j,cnt_set(j))=tmp2(k);
        end
    end
end
change_fatlif_set=fatlif_set./fatlif_init_set;

%Get dam in sets
dam_in_set_unique_cell=unique(dam_in_set_cell);
ndamsets=length(dam_in_set_unique_cell);


%% PROCESS: Regression on data
fprintf('...regression');

%Memory alloc based on above
fitted_line_log_set=zeros(nsets,size(fatlif_init_set,2));
fitted_line_set=zeros(nsets,size(fatlif_init_set,2));

%Create a log data set
fatlif_init_set_log=log10(fatlif_init_set); %NOTE: Will create -InF for all zero entries! This is ignored below..
fatlif_log_set=log10(fatlif_set);

for i=1:nsets
    %Create a poly-fit (order=1, i.e. linear) to data
    if any(member_in_set==i)
        [polynom_set(i,:),ErrorEst(i,:)]=polyfit(fatlif_init_set_log(i,1:cnt_set(i)),fatlif_log_set(i,1:cnt_set(i)),1);
        tmp=polyval(polynom_set(i,:),fatlif_init_set_log(i,1:cnt_set(i)),ErrorEst(i,:));   
        for k=1:length(tmp)
            fitted_line_log_set(i,k)=tmp(k);
            fitted_line_set(i,k)=10.^tmp(k);
        end
    end
end

%Create limit lines, i.e. change +/- 20 %
%Linear: No change (y=x)
x_regr_set=fatlif_init_set;

%Make high/low limits based on input
delta_fat=threshold_fat/100;
y_low_set=(1-delta_fat)*x_regr_set;
y_high_set=(1+delta_fat)*x_regr_set;


%% PROCESS: Calculate ratio for initial/damaged fatlif
fatlif_init_mat=ones(1,size(fatlif,1))'*fatlif_init;
change_fatlif=fatlif./fatlif_init_mat;


%% PROCESS: Mean and Std for a set sorted against all runs
fprintf('...statistic');

mus=zeros(1,nsets);
stds=zeros(1,nsets);

mx=0.8;

for i=1:nsets
    tmp=change_fatlif(:,member_in_set==i);
    mus(i)=mean(tmp(tmp<=mx));
    stds(i)=std(tmp(tmp<=mx));
end

f=figure('Visible','Off');
plot(1:nsets,[mus;stds],'*');
xlim([0.5 nsets+0.5]);
legend('Mean','Std','Location','East');
title(['CHANGE IN FATIGUE LIFE (R_3<=', num2str(mx) ')'],'FontSize',12);
xlabel('Set number');
ylabel('Value');


set(f, 'PaperUnits', 'points');
set(f, 'PaperSize', [500 360]);
set(f, 'PaperPositionMode', 'manual');
set(f, 'PaperPosition', [0 0 500 360]);
saveas(f,[pwd '\MATLAB PLOTS\FigureMeanStdAllSets.fig'],'fig');

close(f);
%% PROCESS: Mean and Std for a set sorted against sets
fprintf('...');
muss=zeros(ndamsets,nsets);
stdss=zeros(ndamsets,nsets);

mx=1;

tmp1=unique(dam_in_set);
for i=1:ndamsets
    for j=1:nsets
        tmp=change_fatlif(dam_in_set==tmp1(i),member_in_set==j);
        muss(i,j)=mean(tmp(tmp<=mx));
        stdss(i,j)=std(tmp(tmp<=mx));
    end
end


f=figure('Visible','Off');
%Create a describing legend
leg=cell(nsets,1);
nmb=(1:nsets);
for i=1:nsets
    leg(i)={[num2str(nmb(i)) ': ' char(set_names(i))]};
end
leg=char(leg);
% 
% %Modify mu to fit a pcolor plot
% muss_pcol=[muss zeros(size(muss,1),1)];
% muss_pcol=[muss_pcol; zeros(1,size(muss_pcol,2))];
% 
% %Create meshgrids so mu gets centered on ints(=set numbers)
% yrange=[unique(dam_in_set) max(dam_in_set)+1]-0.5;
% xrange=(1:nsets+1)-0.5;
% [x y]=meshgrid(xrange,yrange);
% 
% pcolor(x,y,muss_pcol);
% colormap('Hot');
% colorbar('Location','WestOutside');
% legend(leg,'Location','EastOutside');
% title(['MEAN CHANGE IN FATIGUE LIFE (R_3<=', num2str(mx) ')'],'FontSize',12);
% xlabel('Set number');
% ylabel('Damaged set number');
% 
% set(f, 'PaperUnits', 'points');
% set(f, 'PaperSize', [500 360]);
% set(f, 'PaperPositionMode', 'manual');
% set(f, 'PaperPosition', [0 0 500 360]);
% saveas(f,[pwd '\MATLAB PLOTS\FigurePcolMeanDamInSetAllSets.fig'],'fig');
% 
% close(f);
% 
% f=figure('Visible','Off');
% 
% %Modify std to fit a pcolor plot
% stdss_pcol=[stdss zeros(size(stdss,1),1)];
% stdss_pcol=[stdss_pcol; zeros(1,size(stdss_pcol,2))];
% 
% pcolor(x,y,stdss_pcol);
% colormap('Hot');
% colormap(flipud(colormap)); %For std, high values are "hot"
% colorbar('Location','WestOutside');
% legend(leg,'Location','EastOutside');
% title(['STD CHANGE IN FATIGUE LIFE (R_3<=', num2str(mx) ')'],'FontSize',12);
% xlabel('Set number');
% ylabel('Damaged set number');
% 
% set(f, 'PaperUnits', 'points');
% set(f, 'PaperSize', [500 360]);
% set(f, 'PaperPositionMode', 'manual');
% set(f, 'PaperPosition', [0 0 500 360]);
% saveas(f,[pwd '\MATLAB PLOTS\FigurePcolStdDamInSetAllSets.fig'],'fig');
% 
% close(f);
%% PLOT: XY and bar plots
if create_plots==true
for i=1:nsets
    if any(member_in_set==i)
        %Get change ratios
        tmp=change_fatlif_set(i,change_fatlif_set(i,:)<=2);
        f1=figure('Visible','Off');
        dbin=2/21;
        bins=dbin/2:dbin:2-dbin/2;
        [N X]=hist(tmp,bins);
        bar(X,N);
        set(gca,'YScale','log');
        xlabel('Ratio fatigue life (R_3');
        ylabel('Frequency');
        title(['HISTOGRAM RATIO FATIGUE LIFE' sprintf('\n') 'FOR SET: ' char(set_names(i))],'FontSize',12);
        
        set(f1, 'PaperUnits', 'points');
        set(f1, 'PaperSize', [500 360]);
        set(f1, 'PaperPositionMode', 'manual');
        set(f1, 'PaperPosition', [0 0 500 360]);
        saveas(f1,[pwd '/MATLAB PLOTS/HISTOGRAM PLOTS PR SET/FigureHistR3Set' strrep(char(set_names(i)),' ','') '.fig'],'fig');

        close(f1);

        %Plot X-Y with regression and +/- X [%]  lines
        f2=figure('Visible','Off');
        loglog(fatlif_init_set(i,1:cnt_set(i)),fitted_line_set(i,1:cnt_set(i)),'g-',fatlif_init_set(i,1:cnt_set(i)),fatlif_set(i,1:cnt_set(i)),'b.',x_regr_set(i,1:cnt_set(i)),y_high_set(i,1:cnt_set(i)),'r--',x_regr_set(i,1:cnt_set(i)),y_low_set(i,1:cnt_set(i)),'r--');
        mn=1.1*min(min(fatlif_init_set(i,1:cnt_set(i))),min(fatlif_set(i,1:cnt_set(i))));
        mx=1.1*max(max(fatlif_init_set(i,1:cnt_set(i))),max(fatlif_set(i,1:cnt_set(i))));
        %axis([mn mx mn mx]);
        xlabel('Initial Fatigue Life');
        ylabel('Damaged Fatigue Life');
        title(['X-Y PLOT FATIGUE LIFE' sprintf('\n') 'FOR SET: ' char(set_names(i))],'FontSize',12);
        legend('Regression Line','Data',[num2str(delta_fat*100) ' % change'],'Location','NorthWest');
        
        set(f2, 'PaperUnits', 'points');
        set(f2, 'PaperSize', [500 360]);
        set(f2, 'PaperPositionMode', 'manual');
        set(f2, 'PaperPosition', [0 0 500 360]);
        saveas(f2,[pwd '/MATLAB PLOTS/XY PLOTS REGRESSION PR SET/FigureXYRegrFatigueLifeSet' strrep(char(set_names(i)),' ','') '.fig'],'fig');

        close(f2);
    end
end
end

%Convert fig to PNG
saveaspng([pwd '\MATLAB PLOTS'],14,14,1,2);
saveaspng([pwd '\MATLAB PLOTS\XY PLOTS REGRESSION PR SET'],14,14,1,2);
saveaspng([pwd '\MATLAB PLOTS\HISTOGRAM PLOTS PR SET'],14,14,1,2);

fprintf('.... \t\tOK!\n');


    
    
    
    
    
    
    